@@ -3,15 +3,16 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  * SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
  */
 
 #include "access.h"
+#include "access_debug.h"
 #include "accessdialog.h"
+#include "request.h"
 #include "utils.h"
 
-#include <QLoggingCategory>
-
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeAccess, "xdp-kde-access")
+#include <QWindow>
 
 AccessPortal::AccessPortal(QObject *parent)
     : QDBusAbstractAdaptor(parent)
@@ -41,15 +42,10 @@ uint AccessPortal::AccessDialog(const QDBusObjectPath &handle,
     qCDebug(XdgDesktopPortalKdeAccess) << "    options: " << options;
 
     auto accessDialog = new ::AccessDialog();
-    Utils::setParentWindow(accessDialog, parent_window);
     accessDialog->setBody(body);
     accessDialog->setTitle(title);
     accessDialog->setSubtitle(subtitle);
 
-    if (options.contains(QStringLiteral("modal"))) {
-        accessDialog->setModal(options.value(QStringLiteral("modal")).toBool());
-    }
-
     if (options.contains(QStringLiteral("deny_label"))) {
         accessDialog->setRejectLabel(options.value(QStringLiteral("deny_label")).toString());
     }
@@ -63,6 +59,14 @@ uint AccessPortal::AccessDialog(const QDBusObjectPath &handle,
     }
 
     // TODO choices
+    Q_UNUSED(results);
+
+    accessDialog->createDialog();
+    Utils::setParentWindow(accessDialog->windowHandle(), parent_window);
+    Request::makeClosableDialogRequest(handle, accessDialog);
+    if (options.contains(QStringLiteral("modal"))) {
+        accessDialog->windowHandle()->setModality(options.value(QStringLiteral("modal")).toBool() ? Qt::WindowModal : Qt::NonModal);
+    }
 
     if (accessDialog->exec()) {
         accessDialog->deleteLater();
